summaryrefslogtreecommitdiffstats
path: root/tools/src/h5repack/h5repack.h
diff options
context:
space:
mode:
Diffstat (limited to 'tools/src/h5repack/h5repack.h')
-rw-r--r--tools/src/h5repack/h5repack.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/tools/src/h5repack/h5repack.h b/tools/src/h5repack/h5repack.h
index a0e0387..52ecb0e 100644
--- a/tools/src/h5repack/h5repack.h
+++ b/tools/src/h5repack/h5repack.h
@@ -131,7 +131,7 @@ typedef struct {
typedef struct named_dt_t {
- haddr_t addr_in; /* Address of the named dtype in the in file */
+ H5O_token_t obj_token; /* Object token for the named dtype in the in file */
hid_t id_out; /* Open identifier for the dtype in the out file */
struct named_dt_t *next; /* Next dtype */
} named_dt_t;